/* BEGIN software license
 *
 * msXpertSuite - mass spectrometry software suite
 * -----------------------------------------------
 * Copyright(C) 2009,...,2018 Filippo Rusconi
 *
 * http://www.msxpertsuite.org
 *
 * This file is part of the msXpertSuite project.
 *
 * The msXpertSuite project is the successor of the massXpert project. This
 * project now includes various independent modules:
 *
 * - massXpert, model polymer chemistries and simulate mass spectrometric data;
 * - mineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 * END software license
 */


#ifndef MONOMER_CROSS_LINK_DLG_HPP
#define MONOMER_CROSS_LINK_DLG_HPP


/////////////////////// Qt includes
#include <QMainWindow>


/////////////////////// Local includes
#include "ui_MonomerCrossLinkDlg.h"
#include "AbstractSeqEdWndDependentDlg.hpp"
#include "SequenceEditorWnd.hpp"


namespace MsXpS
{

namespace massxpert
{


  class Monomer;


  class MonomerCrossLinkDlg : public AbstractSeqEdWndDependentDlg
  {
    Q_OBJECT
    public:
    MonomerCrossLinkDlg(SequenceEditorWnd *editorWnd,
                        /* no polymer **/
                        /* no libXpertMass::PolChemDef **/
                        const QString &settingsFilePath,
                        const QString &applicationName,
                        const QString &description);

    ~MonomerCrossLinkDlg();

    public slots:
    void crossLink();
    void uncrossLink();

    void crossLinkerListWidgetItemSelectionChanged();

    void crossLinkedMonomerListWidgetItemSelectionChanged();
    void crossLinkedMonomerListWidgetItemActivated(QListWidgetItem *);

    void crossLinkListWidgetItemSelectionChanged();
    void crossLinkListWidgetItemActivated(QListWidgetItem *);

    void displayAllCrossLinksChanged(int);
    void crossLinkChangedSlot(libXpertMass::Polymer *);

    void polymerSequenceModifiedSlot();

    private:
    Ui::MonomerCrossLinkDlg m_ui;

    bool m_polymerSequenceModified = false;

    QColor m_crossLinkColor;
    int m_crossLinkPixelSize;

    bool populateCrossLinkerList();
    bool populateCrossLinkedMonomerList();
    bool populateCrossLinkList(bool = true);

    bool parseTargetMonomerString(QList<const libXpertMass::Monomer *> *);

    bool initialize();

    void readSettings();
    void writeSettings();
  };

} // namespace massxpert

} // namespace MsXpS


#endif // MONOMER_CROSS_LINK_DLG_HPP
